@@ -18,8 +18,14 @@ sub setup {
 		exit 1;
 	};
 	$Test_DB = Test::TempDatabase->create(no_drop => $nd
-		, dbname => $ENV{APACHE_SWIT_DB_NAME}, schema => $sc
+		, dbname => $ENV{APACHE_SWIT_DB_NAME}
 		, dbi_args => ($args || Apache::SWIT::DB::Connection->DBIArgs));
+	# -f option doesn't always work for large objects
+	conv_silent_system("psql --single-transaction"
+			. " -d $ENV{APACHE_SWIT_DB_NAME}"
+			. " < $ENV{APACHE_SWIT_LOAD_DB}")
+		if ($ENV{APACHE_SWIT_LOAD_DB});
+	$sc->new($Test_DB->handle)->run_updates;
 	Apache::SWIT::DB::Connection->instance($Test_DB->handle);
 }
 
